NamedToolChoice class final

Inheritance

Constructors

NamedToolChoice(String name)
Creates it.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The only function the model may call.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited