ToolChoice class sealed

What the extractor is allowed to answer.

Implementers

Constructors

ToolChoice.function(String name)
This exact function and no other.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

any → const ToolChoice
A call is mandatory — "no function fits" is not an allowed answer.
auto → const ToolChoice
Call a function when one fits, otherwise report that none does.