auto constant
ToolChoice
const auto
Call a function when one fits, otherwise report that none does.
Implementation
static const ToolChoice auto = AutoToolChoice();
Call a function when one fits, otherwise report that none does.
static const ToolChoice auto = AutoToolChoice();