downgradeNotice property
String?
get
downgradeNotice
Set when the backend answered with a different model than requested.
Implementation
String? get downgradeNotice => _downgradeNotice;
Set when the backend answered with a different model than requested.
String? get downgradeNotice => _downgradeNotice;