TextAttachment class
A plain-text file attached to a turn. Binary files are not supported by the anonymous flow; extract text in your app first.
Constructors
- TextAttachment({required String name, required String content})
-
Creates an attachment.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited